"use client";
import { ChangeEvent, FC, PropsWithChildren, useMemo, useState } from "react";
import clsx from "clsx";
import Link from "next/link";
import ButtonOwn from "@/components/ButtonOwn";
import "./style.scss";
import { useTranslations } from "next-intl";

/**
 * @description 登录注册From表单
 * @param {string} type 使用类型
 * @param {string} msgError 错误提示 login 或 register
 * @param {(params: any) => void} callbackFun 回调方法
 */
export interface FromComProps {
    type?: string;
    msgError?: string;
    callbackFun?: (params: any) => void;
}

const FromCom: FC<PropsWithChildren<FromComProps>> = ({type = 'login', msgError = '', callbackFun}) => {
    const t = useTranslations("LoginPage");
    let [pwdVisible, setPwdVisible] = useState(false)
    const spanClassName = clsx("iconfont", {
        "icon-kejian": pwdVisible,
        "icon-bukejian": !pwdVisible,
    });

    let [fromParam, setFromParam] = useState({
        userPhone: '',
        pwd: ''
    })

    const activeCls = useMemo(() => {
        let { userPhone, pwd } = fromParam
        if (userPhone && userPhone.length==11 && pwd && pwd.length>5) {
            return true
        }
        return false
    }, [fromParam]);


    const setInputVal = (e: ChangeEvent<HTMLInputElement>) => {
        const {name, value} = e.target;
        if (name == 'pwd') {
            let pwd = value.replaceAll(/[^a-zA-Z0-9_-]/g, '')
            setFromParam({ ...fromParam, pwd })
            return
        }
        setFromParam({
            ...fromParam,
            [name]: value
        })
    }

    const submitRequest = () => {
        activeCls && callbackFun!(fromParam)
    }

    return (
        <div className="FromCom">
            <div className="phoneInput">
                <span className="after">{t("areaCode")}</span>
                <input name="userPhone" type="tel" value={fromParam.userPhone} onChange={setInputVal} placeholder={t("Celular")} maxLength={11} />
            </div>
            <div className="passwordInput">
                <input name="pwd" type={pwdVisible?'text':'password'} value={fromParam.pwd} onChange={setInputVal} placeholder={t("Senha")} maxLength={12}/>
                <span className={spanClassName} onClick={() => setPwdVisible(!pwdVisible)}></span>
            </div>
            <div className="btnContent">
                { msgError && <div className="tips"> {msgError} </div> }
                <ButtonOwn active={activeCls} callbackFun={submitRequest}>{type == 'login'? 'Login' : t("register")}</ButtonOwn>
            </div>
            <div className="link">
                {
                    type == 'login' ? (
                        <>
                            <Link href="/br/resetPhone">{t("forgetPwd")}</Link>
                            <Link href="/br/register">{t("registerGo")}</Link>
                        </>
                    ) : <Link href="/br/login" className="active" replace>{t("loginGo")}</Link>
                }     
            </div>
        </div>
    );
};

export default FromCom;
