"use client";
import { usePathname, useRouter } from "@/i18n";
import { useGlobalStore } from "@/stores";
import clsx from "clsx";
import { FC, ReactNode, useEffect, useState } from "react";
import "./style.scss";

/**
 * @description 底部Tab组件
 * @param children 插槽内容
 *
 */
export interface FooterProps {
    children?: ReactNode;
}

const tabList = [
    {
        iconSpanName: "icon-home",
        label: "Início",
        path: "/",
    },
    {
        iconSpanName: "icon-qianbao1",
        label: "Depósito",
        path: "/deposit",
    },
    {
        iconSpanName: "icon-afiliado",
        label: "Afiliado",
        path: "/affiliate/summary",
    },
    {
        iconSpanName: "icon-tiyu",
        label: "Esportes",
        path: "/sports",
    },
    {
        iconSpanName: "icon-yonghu",
        label: "Perfil",
        path: "/profile",
    },
];
const Footer: FC = () => {
    const { token } = useGlobalStore();

    const pathname = usePathname();
    const [tabActiveName, setTabActiveName] = useState("/");

    useEffect(() => {
        setTabActiveName(pathname);
    }, [pathname]);

    const router = useRouter();

    const goPage = (path = "/") => {
        if (!token && (path == "/deposit" || path == "/profile")) {
            router.push(`/login?redirect=${path}`);
            return;
        }
        setTabActiveName(path);
        router.push(path);
    };

    return (
        <footer className={"footer-placeholder"}>
            <div className="footer-box">
                <ul>
                    {tabList.map((item, index) => {
                        return (
                            <li
                                className={clsx(item.path == tabActiveName && "active")}
                                onClick={() => goPage(item.path)}
                                key={index}
                            >
                                <div className="icon-box">
                                    {index == 2 ? (
                                        <>
                                            <i className="icon-afiliado"></i>
                                            <i className="icon-rs"></i>
                                        </>
                                    ) : (
                                        <span
                                            className={clsx("iconfont", item.iconSpanName)}
                                        ></span>
                                    )}
                                    {index == 3 && <b className="icon-hot"></b>}
                                </div>
                                <label>{item.label}</label>
                            </li>
                        );
                    })}
                </ul>
            </div>
        </footer>
    );
};

export default Footer;
