"use client";
import { getUserMoneyApi } from "@/api/user";
import { Link } from "@/i18n";
import { useGlobalStore } from "@/stores";
import { useWalletStore } from "@/stores/useWalletStore";
import { useRequest } from "ahooks";
import clsx from "clsx";
import { useTranslations } from "next-intl";
import { FC, memo, ReactNode } from "react";
import HeaderTitle from "./HerderTitle";
import styles from "./style.module.scss";
/**
 * @description HeaderProps
 * @param {boolean} headerPlaceholder 是否展示展位元素
 * @param {() => ReactNode} headerRender 自定义渲染
 */
export interface HeaderProps {
    headerPlaceholder?: boolean;
    headerRender?: () => ReactNode;
    menuHandler?: () => void;
    menuRender?: () => ReactNode;
}

const cs = clsx(["iconfont icon-gengduo", styles.menu]);

const DefaultHeader: FC<HeaderProps> = (props) => {
    const { menuHandler, menuRender } = props;
    const t = useTranslations("Header");
    const { token, userInfo } = useGlobalStore();
    const score = useWalletStore((state) => state.score);
    const setScore = useWalletStore((state) => state.setScore);
    const getUserMoneyHandler = () => {
        if (token) {
            return getUserMoneyApi();
        }
        return Promise.reject();
    };

    useRequest(getUserMoneyHandler, {
        pollingInterval: 3000,
        pollingWhenHidden: true,
        pollingErrorRetryCount: 3,
        staleTime: 5000,
        refreshDeps: [token],
        onError: (error) => {},
        onSuccess: (res) => {
            if (res.data.Score) {
                setScore(res.data.Score);
            }
        },
    });

    return (
        <div className={styles.headerMain}>
            <div className={styles.headerLeft} onClick={menuHandler}>
                {(menuRender && menuRender()) ?? <div className={cs}></div>}
            </div>
            <HeaderTitle />
            <div className={styles.headerRight}>
                <div className={styles.right}>
                    {userInfo ? (
                        <>
                            <Link href={"/profile"}>
                                <div className={"flex items-center text-[0.12rem]"}>
                                    <i className={"iconfont icon-yonghu mr-[0.03rem]"}></i>
                                    <span>{score}</span>
                                </div>
                            </Link>

                            <Link href={"/deposit"} className={styles.rightActive}>
                                {t("deposit")}
                            </Link>
                        </>
                    ) : (
                        <>
                            <Link href={"/login?redirect=/"}>{t("login")}</Link>
                            <Link href={"/register?redirect=/"} className={styles.rightActive}>
                                {t("register")}
                            </Link>
                        </>
                    )}
                </div>
            </div>
        </div>
    );
};

const Header: FC<HeaderProps> = (props) => {
    const { headerPlaceholder = true, headerRender, ...other } = props;
    const cs = clsx({
        [styles.placeholder]: headerPlaceholder,
    });
    return (
        <header className={cs}>
            <div className={styles.headerWrap}>
                {headerRender ? headerRender() : <DefaultHeader {...other} />}
            </div>
        </header>
    );
};
export default memo(Header);
