import { create } from "zustand";
import { createJSONStorage, devtools, persist } from "zustand/middleware";

interface State {
    history: string[];
}

interface Action {
    setHistory: (history: State["history"]) => void;
}

export const useSearchStore = create<State & Action>()(
    devtools(
        persist(
            (set) => {
                return {
                    history: ["for"],
                    setHistory: (value: State["history"]) =>
                        set({
                            history: value,
                        }),
                };
            },
            {
                name: "searchHistory",
                storage: createJSONStorage(() => localStorage),
            }
        ),
        { name: "searchHistory" }
    )
);
